# PyVerdict

PyVerdict is the Python interface to VerdictDB.

Visit https://github.com/mozafari/verdictdb to find more details about the project.


## Build and Deploy

This builds the VerdictDB jar and copy it into pyverdict's lib folder.
```
python build_lib.py
```

## Development

To install and keep developing
```
python setup.py develop
```

To uninstall
```
python setup.py develop --uninstall
```
